"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.storeStatus = void 0;
const path_1 = __importDefault(require("path"));
const store_cafs_1 = require("@pnpm/store.cafs");
const get_context_1 = require("@pnpm/get-context");
const lockfile_utils_1 = require("@pnpm/lockfile-utils");
const logger_1 = require("@pnpm/logger");
const dp = __importStar(require("@pnpm/dependency-path"));
const dint_1 = __importDefault(require("dint"));
const load_json_file_1 = __importDefault(require("load-json-file"));
const p_filter_1 = __importDefault(require("p-filter"));
const extendStoreStatusOptions_1 = require("./extendStoreStatusOptions");
async function storeStatus(maybeOpts) {
    const reporter = maybeOpts?.reporter;
    if ((reporter != null) && typeof reporter === 'function') {
        logger_1.streamParser.on('data', reporter);
    }
    const opts = await (0, extendStoreStatusOptions_1.extendStoreStatusOptions)(maybeOpts);
    const { storeDir, skipped, virtualStoreDir, wantedLockfile, } = await (0, get_context_1.getContextForSingleImporter)({}, {
        ...opts,
        extraBinPaths: [], // ctx.extraBinPaths is not needed, so this is fine
    });
    if (!wantedLockfile)
        return [];
    const pkgs = Object.entries(wantedLockfile.packages ?? {})
        .filter(([depPath]) => !skipped.has(depPath))
        .map(([depPath, pkgSnapshot]) => {
        const id = (0, lockfile_utils_1.packageIdFromSnapshot)(depPath, pkgSnapshot);
        return {
            depPath,
            id,
            integrity: pkgSnapshot.resolution.integrity,
            pkgPath: depPath,
            ...(0, lockfile_utils_1.nameVerFromPkgSnapshot)(depPath, pkgSnapshot),
        };
    });
    const cafsDir = path_1.default.join(storeDir, 'files');
    const modified = await (0, p_filter_1.default)(pkgs, async ({ id, integrity, depPath, name }) => {
        const pkgIndexFilePath = integrity
            ? (0, store_cafs_1.getFilePathInCafs)(cafsDir, integrity, 'index')
            : path_1.default.join(storeDir, dp.depPathToFilename(id, maybeOpts.virtualStoreDirMaxLength), 'integrity.json');
        const { files } = await (0, load_json_file_1.default)(pkgIndexFilePath);
        return (await dint_1.default.check(path_1.default.join(virtualStoreDir, dp.depPathToFilename(depPath, maybeOpts.virtualStoreDirMaxLength), 'node_modules', name), files)) === false;
    }, { concurrency: 8 });
    if ((reporter != null) && typeof reporter === 'function') {
        logger_1.streamParser.removeListener('data', reporter);
    }
    return modified.map(({ pkgPath }) => pkgPath);
}
exports.storeStatus = storeStatus;
//# sourceMappingURL=index.js.map